@@ -24,10 +24,12 @@
 #include <config.h>
 #endif
 
+#include "gedit-commands.h"
+#include "gedit-commands-private.h"
+
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
-#include "gedit-commands.h"
 #include "gedit-debug.h"
 #include "gedit-app.h"
 #include "gedit-dirs.h"
@@ -59,6 +61,7 @@ _gedit_cmd_help_about (GtkAction   *action,
 		"Jesse van den Kieboom <jessevdk@gnome.org>",
 		"Paolo Borelli <pborelli@katamail.com>",
 		"Paolo Maggi <paolo@gnome.org>",
+		"S\303\251bastien Lafargue <slafargue@gnome.org>",
 		"S\303\251bastien Wilmet <swilmet@gnome.org>",
 		"Steve Fr\303\251cinaux <steve@istique.net>",
 		NULL
