@@ -25,47 +25,29 @@
 
 G_BEGIN_DECLS
 
-/*
- * Type checking and casting macros
- */
 #define GEDIT_TYPE_ENCODINGS_DIALOG              (gedit_encodings_dialog_get_type())
 #define GEDIT_ENCODINGS_DIALOG(obj)              (G_TYPE_CHECK_INSTANCE_CAST((obj), GEDIT_TYPE_ENCODINGS_DIALOG, GeditEncodingsDialog))
-#define GEDIT_ENCODINGS_DIALOG_CONST(obj)        (G_TYPE_CHECK_INSTANCE_CAST((obj), GEDIT_TYPE_ENCODINGS_DIALOG, GeditEncodingsDialog const))
 #define GEDIT_ENCODINGS_DIALOG_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST((klass), GEDIT_TYPE_ENCODINGS_DIALOG, GeditEncodingsDialogClass))
 #define GEDIT_IS_ENCODINGS_DIALOG(obj)           (G_TYPE_CHECK_INSTANCE_TYPE((obj), GEDIT_TYPE_ENCODINGS_DIALOG))
 #define GEDIT_IS_ENCODINGS_DIALOG_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), GEDIT_TYPE_ENCODINGS_DIALOG))
 #define GEDIT_ENCODINGS_DIALOG_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS((obj), GEDIT_TYPE_ENCODINGS_DIALOG, GeditEncodingsDialogClass))
 
-
-/* Private structure type */
-typedef struct _GeditEncodingsDialogPrivate GeditEncodingsDialogPrivate;
-
-/*
- * Main object structure
- */
-typedef struct _GeditEncodingsDialog GeditEncodingsDialog;
+typedef struct _GeditEncodingsDialog		GeditEncodingsDialog;
+typedef struct _GeditEncodingsDialogClass	GeditEncodingsDialogClass;
+typedef struct _GeditEncodingsDialogPrivate	GeditEncodingsDialogPrivate;
 
 struct _GeditEncodingsDialog
 {
 	GtkDialog dialog;
 
-	/*< private > */
 	GeditEncodingsDialogPrivate *priv;
 };
 
-/*
- * Class definition
- */
-typedef struct _GeditEncodingsDialogClass GeditEncodingsDialogClass;
-
 struct _GeditEncodingsDialogClass
 {
 	GtkDialogClass parent_class;
 };
 
-/*
- * Public methods
- */
 GType		 gedit_encodings_dialog_get_type	(void) G_GNUC_CONST;
 
 GtkWidget	*gedit_encodings_dialog_new		(void);
