@@ -20,11 +20,12 @@
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "gedit-recent.h"
+
 #include <gtk/gtk.h>
 #include <gedit/gedit-document.h>
 #include <string.h>
 
-#include "gedit-recent.h"
 #include "gedit-settings.h"
 
 void
@@ -157,6 +158,7 @@ populate_filter_info (GtkRecentInfo        *info,
 	}
 }
 
+/* The GeditRecentConfiguration struct is allocated and owned by the caller */
 void
 gedit_recent_configuration_init_default (GeditRecentConfiguration *config)
 {
@@ -171,6 +173,7 @@ gedit_recent_configuration_init_default (GeditRecentConfiguration *config)
 
 	config->filter = gtk_recent_filter_new ();
 	gtk_recent_filter_add_application (config->filter, g_get_application_name ());
+	gtk_recent_filter_add_mime_type (config->filter, "text/plain");
 	g_object_ref_sink (config->filter);
 
 	settings = g_settings_new ("org.gnome.gedit.preferences.ui");
@@ -189,6 +192,7 @@ gedit_recent_configuration_init_default (GeditRecentConfiguration *config)
 	config->substring_filter = NULL;
 }
 
+/* The GeditRecentConfiguration struct is owned and destroyed by the caller */
 void
 gedit_recent_configuration_destroy (GeditRecentConfiguration *config)
 {
@@ -205,6 +209,7 @@ gedit_recent_get_items (GeditRecentConfiguration *config)
 	GList *items;
 	GList *retitems = NULL;
 	gint length;
+	gboolean has_substring_filter;
 
 	if (config->limit == 0)
 	{
@@ -219,6 +224,7 @@ gedit_recent_get_items (GeditRecentConfiguration *config)
 	}
 
 	needed = gtk_recent_filter_get_needed (config->filter);
+	has_substring_filter = (config->substring_filter && *config->substring_filter != '\0');
 
 	while (items)
 	{
@@ -243,7 +249,7 @@ gedit_recent_get_items (GeditRecentConfiguration *config)
 		}
 		else
 		{
-			if (config->substring_filter && *config->substring_filter != '\0')
+			if (has_substring_filter)
 			{
 				gchar *uri_lower;
 
