@@ -1,5 +1,23 @@
 #include "gedit-spell-osx.h"
-#include <Cocoa/Cocoa.h>
+#include <gtkosxapplication.h>
+#import <Cocoa/Cocoa.h>
+
+gchar *
+gedit_spell_osx_get_resource_path (void)
+{
+	gchar *id;
+	gchar *ret = NULL;
+
+	id = gtkosx_application_get_bundle_id ();
+
+	if (id != NULL)
+	{
+		ret = gtkosx_application_get_resource_path ();
+	}
+
+	g_free (id);
+	return ret;
+}
 
 gchar *
 gedit_spell_osx_get_preferred_spell_language ()
@@ -9,7 +27,7 @@ gedit_spell_osx_get_preferred_spell_language ()
 
 	pool = [[NSAutoreleasePool alloc] init];
 
-#if MAC_OS_X_VERSION_MIN_REQUIRED > MAC_OS_X_VERSION_10_5
+#if defined(MAC_OS_X_VERSION_10_5) && MAC_OS_X_VERSION_MIN_REQUIRED > MAC_OS_X_VERSION_10_5
 	NSArray *langs;
 
 	langs = [[NSSpellChecker sharedSpellChecker] userPreferredLanguages];
